@@ -1,4 +1,154 @@
-def write_optuna_execution_script(path, inputs, input_branch_name):
+def write_optuna_analyse_script(path, input_branch_name):
+    analyse_script = """{
+ "cells": [
+  {
+   "cell_type": "code",
+   "execution_count": null,
+   "metadata": {},
+   "outputs": [],
+   "source": [
+    "import dvc_cc\n",
+    "import dvc_cc.run\n",
+    "dvc_cc.version.VERSION"
+   ]
+  },
+  {
+   "cell_type": "code",
+   "execution_count": null,
+   "metadata": {},
+   "outputs": [],
+   "source": [
+    "import subprocess\n",
+    "import json\n",
+    "import numpy as np\n",
+    "import optuna\n",
+    "import time"
+   ]
+  },
+  {
+   "cell_type": "code",
+   "execution_count": null,
+   "metadata": {},
+   "outputs": [],
+   "source": [
+    "import os\n",
+    "from pathlib import Path\n",
+    "import optuna\n",
+    "study = optuna.create_study(direction='minimize',\n",
+    "                            study_name='study_1', \n",
+    "                            storage='sqlite:///"""+input_branch_name+""".db?timeout=99999',\n",
+    "                            load_if_exists=True)"
+   ]
+  },
+  {
+   "cell_type": "code",
+   "execution_count": null,
+   "metadata": {},
+   "outputs": [],
+   "source": [
+    "trial = study.best_trial\n",
+    "\n",
+    "print('Accuracy: {}'.format(trial.value))\n",
+    "print(\"Best hyperparameters: {}\".format(trial.params))"
+   ]
+  },
+  {
+   "cell_type": "code",
+   "execution_count": null,
+   "metadata": {},
+   "outputs": [],
+   "source": [
+    "import pandas as pd\n",
+    "df = pd.DataFrame(study.trials_dataframe())\n",
+    "df"
+   ]
+  },
+  {
+   "cell_type": "code",
+   "execution_count": null,
+   "metadata": {},
+   "outputs": [],
+   "source": [
+    "df.groupby('state').count()"
+   ]
+  },
+  {
+   "cell_type": "code",
+   "execution_count": null,
+   "metadata": {},
+   "outputs": [],
+   "source": []
+  },
+  {
+   "cell_type": "code",
+   "execution_count": null,
+   "metadata": {},
+   "outputs": [],
+   "source": [
+    "optuna.visualization.plot_optimization_history(study)"
+   ]
+  },
+  {
+   "cell_type": "code",
+   "execution_count": null,
+   "metadata": {},
+   "outputs": [],
+   "source": [
+    "optuna.visualization.plot_slice(study)"
+   ]
+  },
+  {
+   "cell_type": "code",
+   "execution_count": null,
+   "metadata": {},
+   "outputs": [],
+   "source": [
+    "#optuna.visualization.plot_contour(study)#, params=['n_estimators', 'max_depth'])"
+   ]
+  },
+  {
+   "cell_type": "code",
+   "execution_count": null,
+   "metadata": {},
+   "outputs": [],
+   "source": [
+    "optuna.visualization.plot_contour(study, params=['learning_rate', 'model_kernels'])"
+   ]
+  },
+  {
+   "cell_type": "code",
+   "execution_count": null,
+   "metadata": {},
+   "outputs": [],
+   "source": []
+  }
+ ],
+ "metadata": {
+  "kernelspec": {
+   "display_name": "dvc-cc",
+   "language": "python",
+   "name": "dvc-cc"
+  },
+  "language_info": {
+   "codemirror_mode": {
+    "name": "ipython",
+    "version": 3
+   },
+   "file_extension": ".py",
+   "mimetype": "text/x-python",
+   "name": "python",
+   "nbconvert_exporter": "python",
+   "pygments_lexer": "ipython3",
+   "version": "3.7.3"
+  }
+ },
+ "nbformat": 4,
+ "nbformat_minor": 2
+}"""
+    with open(path,'w') as f:
+        print(analyse_script, file=f)
+
+def write_optuna_execution_script(path, inputs, input_branch_name, jobs, num_of_trials):
     with open(path,'w') as f:
 
         print('# !/usr/bin/env python', file=f)
@@ -28,7 +178,7 @@ def write_optuna_execution_script(path, inputs, input_branch_name):
                 print('    values.append(trial.suggest_categorical("'+k+'", ['+v+'])'
                       +')', file=f)
             else:
-                print('    values.append('+v+') // ' + k, file=f)
+                print('    values.append('+v+') # ' + k, file=f)
 
         print("    result_branch = '"+input_branch_name+"_'+str(time.time_ns())", file=f)
         print("    dvc_save_path = 'dvc/' + result_branch", file=f)
@@ -68,7 +218,7 @@ def write_optuna_execution_script(path, inputs, input_branch_name):
         print('                            load_if_exists=True', file=f)
         print('                           )', file=f)
         print('', file=f)
-        print('study.optimize(startbla, n_trials=300,n_jobs=150)', file=f)
+        print('study.optimize(startbla, n_trials='+str(num_of_trials)+',n_jobs='+str(jobs)+')', file=f)
 
 
 # parameters
@@ -113,16 +263,26 @@ def write_metric_getter_script(path, input_branch_name, metric_path, save_summar
         print('', file=f)
 
 
+def setting_batch_concurrency_limit():
+    from pathlib import Path
+    from ruamel.yaml import YAML
+
+    with open(str(Path(".dvc_cc/cc_config.yml")), 'r') as stream:
+        settings = yaml.safe_load(stream)
+
+    return settings['execution']['settings']['batchConcurrencyLimit']
+
 
 def create_optuna_directories(input_branch_name, vc):
     # 1. copy current directory
+    import os
     import shutil
     jobstarter_path = '../'+os.getcwd().split('/')[-1]+'_'+input_branch_name.split('_')[1]+'_JobStarter'
     shutil.copytree('.', jobstarter_path)
 
     metric_path = '../' + os.getcwd().split('/')[-1] + '_MetricGetter'
     if not os.path.exists(metric_path):
-        shutil.copytree('.', jobstarter_path)
+        shutil.copytree('.', metric_path)
 
     # 2. get input values
     inputs = {}
@@ -130,10 +290,19 @@ def create_optuna_directories(input_branch_name, vc):
         inp = input(str(v.varname + ' (' + v.vartype + '): '))
         inputs[v.varname] = [v.vartype, inp]
 
-    # 3. Create optuna script
-    write_optuna_execution_script(path=jobstarter_path+'/run_optuna.py',inputs=inputs, input_branch_name=input_branch_name)
+    bcl = setting_batch_concurrency_limit()
+    print()
+    print('It is possible that ' + str(bcl) + ' (Batch Concurrency Limit) jobs can run in parallel.')
+    num_of_trials = input('How many trials do you want?: ')
 
-    # 4. Create metrics getter script
+
+    # 3. Create optuna script,
+    write_optuna_execution_script(path=jobstarter_path+'/run_optuna.py',inputs=inputs, input_branch_name=input_branch_name, jobs=bcl, num_of_trials=num_of_trials)
+    # 4. analyse script
+    write_optuna_analyse_script(jobstarter_path+'/analyse_optuna.ipynb', input_branch_name)
+
+    # 5. Create metrics getter script
     # TODO: The 'loss.metric' must be a variable !
     write_metric_getter_script(metric_path + '/get_metrics.py', input_branch_name,
-                               'loss.metric', jobstarter_path+'/metrics.json')
\ No newline at end of file
+                               'loss.metric', jobstarter_path+'/metrics.json')
+
